@@ -35,8 +35,11 @@
 //! )
 //! ```
 
-#[macro_use]
-extern crate lazy_static;
+#[cfg(test)]
+extern crate quickcheck;
+#[cfg(test)]
+#[macro_use(quickcheck)]
+extern crate quickcheck_macros;
 
 pub use bodies::Bodies;
 pub use body::Body;
