@@ -8,7 +8,7 @@ use thiserror::Error;
 
 use crate::{body::Body, Fragment};
 
-/// A `Trailer` you might see a in a `CommitMessage`, for example
+/// A [`Trailer`] you might see a in a [`CommitMessage`], for example
 /// 'Co-authored-by: Billie Thompson <billie@example.com>'
 #[derive(Debug, Clone, Eq, Ord, PartialOrd)]
 pub struct Trailer {
@@ -17,9 +17,9 @@ pub struct Trailer {
 }
 
 impl Trailer {
-    /// Create a new `Trailer`
+    /// Create a new [`Trailer`]
     ///
-    /// This creates a new element that represents the sort of `Trailers` you
+    /// This creates a new element that represents the sort of [`Trailers`] you
     /// get at the end of commits
     ///
     /// For example there's `Co-authored-by`, `Relates-to`, and `Signed-off-by`
@@ -37,14 +37,14 @@ impl Trailer {
     /// )
     /// ```
     #[must_use]
-    pub fn new(key: &str, value: &str) -> Trailer {
-        Trailer {
+    pub fn new(key: &str, value: &str) -> Self {
+        Self {
             key: String::from(key),
             value: String::from(value),
         }
     }
 
-    /// Get the key of the `Trailer`
+    /// Get the key of the [`Trailer`]
     ///
     /// # Example
     ///
@@ -62,7 +62,7 @@ impl Trailer {
         self.key.clone()
     }
 
-    /// Get the value of the `Trailer`
+    /// Get the value of the [`Trailer`]
     ///
     /// # Example
     ///
@@ -100,7 +100,7 @@ impl From<Trailer> for String {
 impl From<Trailer> for Fragment {
     fn from(trailer: Trailer) -> Self {
         let trailer: String = trailer.into();
-        Fragment::Body(Body::from(trailer))
+        Self::Body(Body::from(trailer))
     }
 }
 
@@ -118,7 +118,7 @@ impl TryFrom<Body> for Trailer {
             .get(1)
             .ok_or_else(|| Error::new_not_a_trailer(&body))?;
 
-        Ok(Trailer::new(key, value))
+        Ok(Self::new(key, value))
     }
 }
 
@@ -133,9 +133,9 @@ pub enum Error {
 }
 
 impl Error {
-    fn new_not_a_trailer(body: &Body) -> Error {
+    fn new_not_a_trailer(body: &Body) -> Self {
         let text: String = body.clone().into();
-        Error::NotATrailer(text.clone(), (0, text.len()))
+        Self::NotATrailer(text.clone(), (0, text.len()))
     }
 }
 
